%undefine __cmake_in_source_build

Name:           cppcheck
Version:        2.13.0
Release:    1%{?dist}
Summary:        Tool for static C/C++ code analysis
License:        GPL-3.0-or-later
URL:            http://cppcheck.wiki.sourceforge.net/
Source0:        https://github.com/danmar/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

Patch0:         cppcheck-2.11-translations.patch
Patch1:         cppcheck-2.13.0-fix_test_failure_on_32bit_platform.patch

BuildRequires:  gcc-c++
BuildRequires:  pcre-devel
BuildRequires:  docbook-style-xsl
BuildRequires:  libxslt
BuildRequires:  pandoc
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  tinyxml2-devel >= 2.1.0
BuildRequires:  zlib-devel
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  qt5-qtbase-devel
BuildRequires:  qt5-qttools-devel
BuildRequires:  qt5-linguist
BuildRequires:  make


%description
Cppcheck is a static analysis tool for C/C++ code. Unlike C/C++
compilers and many other analysis tools it does not detect syntax
errors in the code. Cppcheck primarily detects the types of bugs that
the compilers normally do not detect. The goal is to detect only real
errors in the code (i.e. have zero false positives).

%package gui
Summary:        Graphical user interface for cppcheck
Requires:       %{name} = %{version}-%{release}

%description gui
This package contains the graphical user interface for cppcheck.

%package htmlreport
Summary:        HTML reporting for cppcheck
Requires:       %{name} = %{version}-%{release}
Requires:       python3-pygments

%description htmlreport
This package contains the Python utility for generating html reports
from xml files first generated using cppcheck.

%prep
%setup -q
%patch0 -p1 -b .translations
%patch1 -p1 -b .fix_test_failure
rm -r externals/tinyxml2
cd gui/help
qhelpgenerator-qt5 online-help.qhcp -o online-help.qhc

%build
make DB2MAN=%{_datadir}/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl man
pandoc man/manual.md -o man/manual.html -s --number-sections --toc
pandoc man/reference-cfg-format.md -o man/reference-cfg-format.html -s --number-sections --toc

%cmake -DCMAKE_BUILD_TYPE=Release -DUSE_MATCHCOMPILER=yes -DHAVE_RULES=yes -DBUILD_GUI=1 -DBUILD_SHARED_LIBS:BOOL=OFF -DBUILD_TESTS=yes -DFILESDIR=%{_datadir}/Cppcheck -DUSE_BUNDLED_TINYXML2=OFF -DENABLE_OSS_FUZZ=OFF
%cmake_build

%install
rm -rf %{buildroot}
%cmake_install
install -D -p -m 644 cppcheck.1 %{buildroot}%{_mandir}/man1/cppcheck.1
desktop-file-validate %{buildroot}%{_datadir}/applications/cppcheck-gui.desktop
install -D -p -m 644 gui/cppcheck-gui.png %{buildroot}%{_datadir}/pixmaps/cppcheck-gui.png
install -D -p -m 644 gui/help/online-help.qhc %{buildroot}%{_datadir}/Cppcheck/help/online-help.qhc
install -D -p -m 644 gui/help/online-help.qch %{buildroot}%{_datadir}/Cppcheck/help/online-help.qch
install -D -p -m 755 htmlreport/cppcheck-htmlreport %{buildroot}%{_bindir}/cppcheck-htmlreport
grep -l "#\!/usr/bin/env python3" %{buildroot}%{_datadir}/Cppcheck/addons/*.py | xargs chmod +x

%check
cd %{_vpath_builddir}/bin
./testrunner -g -q

%files
%doc AUTHORS man/manual.html man/reference-cfg-format.html
%license COPYING
%{_datadir}/Cppcheck/
%{_bindir}/cppcheck
%{_mandir}/man1/cppcheck.1*

%files gui
%{_bindir}/cppcheck-gui
%{_datadir}/applications/cppcheck-gui.desktop
%{_datadir}/pixmaps/cppcheck-gui.png
%{_datadir}/icons/hicolor/64x64/apps/cppcheck-gui.png
%{_datadir}/icons/hicolor/scalable/apps/cppcheck-gui.svg

%files htmlreport
%{_bindir}/cppcheck-htmlreport

%changelog
* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.13.0-1
- initial build
